OC.L10N.register(
    "core",
    {
    "Please select a file." : "Bitte eine Datei wählen.",
    "File is too big" : "Datei ist zu groß",
    "The selected file is not an image." : "Die ausgewählte Datei ist kein Bild.",
    "The selected file cannot be read." : "Die ausgewählte Datei kann nicht gelesen werden.",
    "The file was uploaded" : "Die Datei wurde hochgeladen",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die hochgeladene Datei übersteigt das Limit upload_max_filesize in der Datei php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die hochgeladene Datei übersteigt das Limit MAX_FILE_SIZE im HTML-Formular",
    "The file was only partially uploaded" : "Die Datei wurde nur teilweise hochgeladen",
    "No file was uploaded" : "Keine Datei wurde hochgeladen",
    "Missing a temporary folder" : "Temporärer Ordner nicht vorhanden",
    "Could not write file to disk" : "Die Datei konnte nicht auf die Festplatte geschrieben werden",
    "A PHP extension stopped the file upload" : "Eine PHP-Erweiterung hat das Hochladen der Datei gestoppt",
    "Invalid file provided" : "Ungültige Datei zur Verfügung gestellt",
    "No image or file provided" : "Es wurde weder ein Bild noch eine Datei zur Verfügung gestellt",
    "Unknown filetype" : "Unbekannter Dateityp",
    "An error occurred. Please contact your admin." : "Es ist ein Fehler aufgetreten. Bitte kontaktiere deine Administration.",
    "Invalid image" : "Ungültiges Bild",
    "State token does not match" : "Status-Token stimmen nicht überein",
    "Invalid app password" : "Ungültiges App-Passwort",
    "Could not complete login" : "Anmeldung konnte nicht abgeschlossen werden",
    "State token missing" : "Zustandstoken fehlt",
    "Your login token is invalid or has expired" : "Dein Anmelde-Token ist ungültig oder abgelaufen",
    "Please use original client" : "Bitte den Original-Client verwenden",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Diese Community-Version von Nextcloud wird nicht unterstützt und (Push-)Benachrichtigungen sind nur begrenzt verfügbar.",
    "Login" : "Anmelden",
    "Unsupported email length (>255)" : "Nicht unterstützte E-Mail-Adresslänge (>255)",
    "Password reset is disabled" : "Passwort-Reset ist deaktiviert",
    "Could not reset password because the token is expired" : "Das Passwort konnte nicht zurückgesetzt werden, da das Token abgelaufen ist",
    "Could not reset password because the token is invalid" : "Das Passwort konnte nicht zurückgesetzt werden, da das Token ungültig ist",
    "Password is too long. Maximum allowed length is 469 characters." : "Passwort ist zu lang. Die maximal zulässige Länge beträgt 469 Zeichen.",
    "%s password reset" : "%s-Passwort zurücksetzen",
    "Password reset" : "Passwort zurücksetzen",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klicke zum Zurücksetzen des Passworts auf die folgende Schaltfläche. Wenn du das Zurücksetzen des Passworts nicht angefordert hast, ignoriere diese E-Mail.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klicke zum Zurücksetzen des Passworts auf den folgenden Link. Wenn du das Zurücksetzen des Passworts nicht angefordert hast, ignoriere diese E-Mail.",
    "Reset your password" : "Setze dein Passwort zurück",
    "The given provider is not available" : "Der angegebene Anbieter ist nicht verfügbar",
    "Task not found" : "Aufgabe nicht gefunden",
    "Internal error" : "Interner Fehler",
    "Not found" : "Nicht gefunden",
    "Node is locked" : "Knoten ist gesperrt",
    "Bad request" : "Fehlerhafte Anfrage",
    "Input text is too long" : "Eingabetext ist zu lang",
    "Requested task type does not exist" : "Angeforderter Aufgabentyp existiert nicht",
    "Necessary language model provider is not available" : "Erforderlicher Sprachmodellanbieter ist nicht verfügbar",
    "No text to image provider is available" : "Es ist kein Text-zu-Bild-Anbieter verfügbar",
    "Image not found" : "Bild nicht gefunden",
    "No translation provider available" : "Kein Übersetzungsanbieter verfügbar",
    "Could not detect language" : "Sprache konnte nicht erkannt werden",
    "Unable to translate" : "Kann nicht übersetzt werden",
    "No valid filters provided" : "Keine gültigen Filter angegeben",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Reparaturschritt:",
    "Repair info:" : "Reparaturinformation:",
    "Repair warning:" : "Reparaturwarnung:",
    "Repair error:" : "Reparaturfehler:",
    "Nextcloud Server" : "Nextcloud-Server",
    "Some of your link shares have been removed" : "Einige der geteilten Freigaben wurden entfernt",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Aufgrund eines Sicherheitsfehlers mussten einige der geteilten Freigaben entfernt werden. Weitere Informationen im Link.",
    "The account limit of this instance is reached." : "Das Kontenlimit dieser Instanz ist erreicht.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Gib deinen Abonnementschlüssel in der Support-App ein, um das Konto-Limit zu erhöhen. Damit erhältst du auch alle zusätzlichen Vorteile, die Nextcloud Enterprise bietet. Dies ist für den Betrieb in Unternehmen sehr zu empfehlen.",
    "Learn more ↗" : "Erfahre mehr ↗",
    "Preparing update" : "Update vorbereiten",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Bitte den Kommandozeilen-Updater verwenden, die Browser-Aktualisierung ist in der config.php deaktiviert.",
    "Turned on maintenance mode" : "Wartungsmodus eingeschaltet",
    "Turned off maintenance mode" : "Wartungsmodus ausgeschaltet",
    "Maintenance mode is kept active" : "Wartungsmodus bleibt aktiviert",
    "Updating database schema" : "Das Datenbankschema wird aktualisiert",
    "Updated database" : "Datenbank aktualisiert",
    "Update app \"%s\" from App Store" : "Aktualisiere die App \"%s\" aus dem App-Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Prüft, ob das Datenbankschema für %s aktualisiert werden kann (dies kann je nach Datenbankgröße sehr lange dauern)",
    "Updated \"%1$s\" to %2$s" : "\"%1$s\" aktualisiert auf %2$s",
    "Set log level to debug" : "Log-Level auf \"debug\" gesetzt",
    "Reset log level" : "Ursprüngliches Log-Level wiederhergestellt",
    "Starting code integrity check" : "Code-Integrität wird überprüft",
    "Finished code integrity check" : "Code-Integritätsprüfung abgeschlossen",
    "%s (incompatible)" : "%s (inkompatibel)",
    "The following apps have been disabled: %s" : "Folgende Apps wurden deaktiviert: %s",
    "Already up to date" : "Bereits aktuell",
    "Windows Command Script" : "Windows-Befehlsskript",
    "Electronic book document" : "E-Book-Dokument",
    "TrueType Font Collection" : "TrueType-Schriftartensammlung",
    "Web Open Font Format" : "Web Open Font Format",
    "GPX geographic data" : "GPX-Geodaten",
    "Gzip archive" : "Gzip-Archiv",
    "Adobe Illustrator document" : "Adobe Illustrator-Dokument",
    "Java source code" : "Java Quellcode",
    "JavaScript source code" : "JavaScript Quellcode",
    "JSON document" : "JSON-Dokument",
    "Microsoft Access database" : "Microsoft Access-Datenbank",
    "Microsoft OneNote document" : "Microsoft OneNote-Dokument",
    "Microsoft Word document" : "Microsoft Word-Dokument",
    "Unknown" : "Unbekannt",
    "PDF document" : "PDF-Dokument",
    "PostScript document" : "PostScript-Dokument",
    "RSS summary" : "RSS-Zusammenfassung",
    "Android package" : "Android-Paket",
    "KML geographic data" : "KML-Geodaten",
    "KML geographic compressed data" : "Komprimierte KML-Geodaten",
    "Lotus Word Pro document" : "Lotus Word Pro-Dokument",
    "Excel spreadsheet" : "Excel-Tabelle",
    "Excel add-in" : "Excel-Add-in",
    "Excel 2007 binary spreadsheet" : "Excel 2007 Binärtabelle",
    "Excel spreadsheet template" : "Excel-Tabellenvorlage",
    "Outlook Message" : "Outlook-Nachricht",
    "PowerPoint presentation" : "PowerPoint-Präsentation",
    "PowerPoint add-in" : "PowerPoint Add-in",
    "PowerPoint presentation template" : "PowerPoint-Präsentationsvorlage",
    "Word document" : "Word Dokument",
    "ODF formula" : "ODF-Formel",
    "ODG drawing" : "ODG-Zeichnung",
    "ODG drawing (Flat XML)" : "ODG-Zeichnung (Flat XML)",
    "ODG template" : "ODG-Vorlage",
    "ODP presentation" : "ODP-Präsentation",
    "ODP presentation (Flat XML)" : "ODP-Präsentation (Flat XML)",
    "ODP template" : "ODP-Vorlage",
    "ODS spreadsheet" : "ODS-Tabelle",
    "ODS spreadsheet (Flat XML)" : "ODS-Tabelle (Flat XML)",
    "ODS template" : "ODS-Vorlage",
    "ODT document" : "ODT-Dokument",
    "ODT document (Flat XML)" : "ODT-Dokument (Flat XML)",
    "ODT template" : "ODT-Vorlage",
    "PowerPoint 2007 presentation" : "PowerPoint 2007-Präsentation",
    "PowerPoint 2007 show" : "PowerPoint 2007-Schau",
    "PowerPoint 2007 presentation template" : "PowerPoint 2007-Präsentationsvorlage",
    "Excel 2007 spreadsheet" : "Excel 2007-Tabelle",
    "Excel 2007 spreadsheet template" : "Excel 2007-Tabellenvorlage",
    "Word 2007 document" : "Word 2007-Dokument",
    "Word 2007 document template" : "Word 2007-Dokumentenvorlage",
    "Microsoft Visio document" : "Microsoft Visio-Dokument",
    "WordPerfect document" : "WordPerfect-Dokument",
    "7-zip archive" : "7-zip-Archiv",
    "Blender scene" : "Blender-Szene",
    "Bzip2 archive" : "Bzip2-Archiv",
    "Debian package" : "Debian-Paket",
    "FictionBook document" : "FictionBook-Dokument",
    "Unknown font" : "Unbekannte Schriftart",
    "Krita document" : "Krita-Dokument",
    "Mobipocket e-book" : "Mobipocket E-Book",
    "Windows Installer package" : "Windows-Installationspaket",
    "Perl script" : "Perl-Skript",
    "PHP script" : "PHP-Skript",
    "Tar archive" : "Tar-Archiv",
    "XML document" : "XML-Dokument",
    "YAML document" : "YAML-Dokument",
    "Zip archive" : "Zip-Archiv",
    "Zstandard archive" : "Zstandard-Archiv",
    "AAC audio" : "AAC-Audio",
    "FLAC audio" : "FLAC-Audio",
    "MPEG-4 audio" : "MPEG-4-Audio",
    "MP3 audio" : "MP3-Audio",
    "Ogg audio" : "Ogg-Audio",
    "RIFF/WAVe standard Audio" : "RIFF/WAVe Standard-Audio",
    "WebM audio" : "WebM-Audio",
    "MP3 ShoutCast playlist" : "MP3 ShoutCast-Wiedergabeliste",
    "Windows BMP image" : "Windows BMP-Bild",
    "Better Portable Graphics image" : "Better Portable Graphics-Bild",
    "EMF image" : "EMF-Bild",
    "GIF image" : "GIF-Bild",
    "HEIC image" : "HEIC-Bild",
    "HEIF image" : "HEIF-Bild",
    "JPEG-2000 JP2 image" : "JPEG-2000 JP2-Bild",
    "JPEG image" : "JPEG-Bild",
    "PNG image" : "PNG-Bild",
    "SVG image" : "SVG-Bild",
    "Truevision Targa image" : "Truevision Targa-Bild",
    "TIFF image" : "TIFF-Bild",
    "WebP image" : "WebP-Bild",
    "Digital raw image" : "Digitales raw-Bild",
    "Windows Icon" : "Windows-Symbol",
    "Email message" : "E-Mail-Nachricht",
    "VCS/ICS calendar" : "VCS/ICS-Kalender",
    "CSS stylesheet" : "CSS-Stylesheet",
    "CSV document" : "CSV-Dokument",
    "HTML document" : "HTML-Dokument",
    "Markdown document" : "Markdown-Dokument",
    "Org-mode file" : "Org-mode-Datei",
    "Plain text document" : "Rohtext-Dokument",
    "Rich Text document" : "Rich Text-Dokument",
    "Electronic business card" : "Elektronische Visitenkarte",
    "C++ source code" : "C++-Quellcode",
    "LDIF address book" : "LDIF-Adressbuch",
    "NFO document" : "NFO-Dokument",
    "PHP source" : "PHP-Quelltext",
    "Python script" : "Python-Skript",
    "ReStructuredText document" : "ReStructuredText-Dokument",
    "3GPP multimedia file" : "3GPP Multimedia-Datei",
    "MPEG video" : "MPEG-Video",
    "DV video" : "DV-Video",
    "MPEG-2 transport stream" : "MPEG-2-Transportstrom",
    "MPEG-4 video" : "MPEG-4-Video",
    "Ogg video" : "Ogg-Video",
    "QuickTime video" : "QuickTime-Video",
    "WebM video" : "WebM-Video",
    "Flash video" : "Flash-Video",
    "Matroska video" : "Matroska-Video",
    "Windows Media video" : "Windows Media-Video",
    "AVI video" : "AVI-Video",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Die Aktualisierung wird durchgeführt. Wenn du dieses Fenster verlässt, kann dies den Aktualisierungsprozess in manchen Umgebungen unterbrechen.",
    "Update to {version}" : "Aktualisierung auf {version}",
    "An error occurred." : "Es ist ein Fehler aufgetreten.",
    "Please reload the page." : "Bitte die Seite neu laden.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Das Update war nicht erfolgreich. Für mehr Informationen <a href=\"{url}\">lies bitte diesen Forenbeitrag</a> zu diesem Thema.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Das Update ist fehlgeschlagen. Bitte melde dieses Problem an die <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud Community</a>.",
    "Continue to {productName}" : "Fortfahren zu {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Die Aktualisierung war erfolgreich. Du wirst in %n Sekunden zu {productName} weitergeleitet.","Die Aktualisierung war erfolgreich. Du wirst in %n Sekunden zu {productName} weitergeleitet."],
    "Applications menu" : "Anwendungs-Menü",
    "Apps" : "Apps",
    "More apps" : "Weitere Apps",
    "_{count} notification_::_{count} notifications_" : ["{count} Benachrichtigung","{count} Benachrichtigungen"],
    "No" : "Nein",
    "Yes" : "Ja",
    "The remote URL must include the user." : "Die entfernte URL muss den Benutzer enthalten.",
    "Invalid remote URL." : "Ungültige entfernte URL.",
    "Failed to add the public link to your Nextcloud" : "Der öffentliche Link konnte nicht zu deiner Nextcloud hinzugefügt werden",
    "Federated user" : "Federated Benutzer",
    "user@your-nextcloud.org" : "benutzer@deine-nextcloud.org",
    "Create share" : "Freigabe erstellen",
    "Direct link copied" : "Direktlink kopiert",
    "Please copy the link manually:" : "Bitte den Link manuell kopieren:",
    "Custom date range" : "Benutzerdefinierter Zeitbereich",
    "Pick start date" : "Startdatum wählen",
    "Pick end date" : "Enddatum wählen",
    "Search in date range" : "Im Datumsbereich suchen",
    "Search in current app" : "In aktueller App suchen ",
    "Clear search" : "Suche löschen",
    "Search everywhere" : "Überall suchen",
    "Searching …" : "Suche …",
    "Start typing to search" : "Beginne mit der Eingabe, um zu suchen",
    "Minimum search length is {minSearchLength} characters" : "Die Mindestsuchlänge beträgt {minSearchLength} Zeichen",
    "No matching results" : "Keine passenden Suchergebnisse",
    "Today" : "Heute",
    "Last 7 days" : "Die letzten 7 Tage",
    "Last 30 days" : "Die letzten 30 Tage",
    "This year" : "Dieses Jahr",
    "Last year" : "Letztes Jahr",
    "Between {startDate} and {endDate}" : "Von {startDate} bis {endDate}",
    "Unified search" : "Einheitliche Suche",
    "Search apps, files, tags, messages" : "Nach Apps, Dateien, Schlagworten und Nachrichten suchen",
    "Places" : "Orte",
    "Date" : "Datum",
    "Search people" : "Personen suchen",
    "People" : "Personen",
    "Filter in current view" : "Filter in aktueller Ansicht",
    "Search connected services" : "Verbundene Dienste durchsuchen",
    "Results" : "Ergebnisse",
    "Load more results" : "Weitere Ergebnisse laden",
    "Search in" : "Suche in",
    "Log in" : "Anmelden",
    "Logging in …" : "Melde an …",
    "Log in to {productName}" : "Anmelden bei {productName}",
    "Wrong login or password." : "Kontoname oder Passwort falsch",
    "This account is disabled" : "Dieses Konto ist deaktiviert",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Es wurden mehrere ungültige Anmeldeversuche von deiner IP-Adresse festgestellt. Daher wird die nächste Anmeldung um 30 Sekunden verzögert.",
    "Account name or email" : "Kontoname oder E-Mail-Adresse",
    "Account name" : "Name des Kontos",
    "Server side authentication failed!" : "Serverseitige Authentifizierung fehlgeschlagen!",
    "Please contact your administrator." : "Bitte kontaktiere die Administration.",
    "Session error" : "Sitzungsfehler",
    "It appears your session token has expired, please refresh the page and try again." : "Der Sitzungstoken scheint abgelaufen zu sein. Bitte diese Seite aktualisieren und neu versuchen.",
    "An internal error occurred." : "Es ist ein interner Fehler aufgetreten.",
    "Please try again or contact your administrator." : "Bitte versuche es noch einmal oder kontaktiere die Administration.",
    "Password" : "Passwort",
    "Remember me" : "An mich erinnern",
    "Log in with a device" : "Mit einem Gerät anmelden",
    "Login or email" : "Kontoname oder E-Mail-Adresse",
    "Your account is not setup for passwordless login." : "Dein Konto ist nicht für eine Anmeldung ohne Passwort eingerichtet.",
    "Your connection is not secure" : "Deine Verbindung ist nicht sicher",
    "Passwordless authentication is only available over a secure connection." : "Anmeldung ohne Passwort ist nur über eine sichere Verbindung möglich",
    "Browser not supported" : "Browser wird nicht unterstützt!",
    "Passwordless authentication is not supported in your browser." : "Anmeldung ohne Passwort wird von deinem Browser nicht unterstützt.",
    "Reset password" : "Passwort zurücksetzen",
    "Back to login" : "Zur Anmeldung wechseln",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Sofern dieses Konto existiert, wurde eine Nachricht zum Zurücksetzen des Passworts an die hinterlegte E-Mail-Adresse gesendet. Wenn du diese E-Mail nicht erhältst, überprüfe deine E-Mail-Adresse und/oder Anmeldenamen, überprüfe deinen Spam-/Junk-Ordner oder bitte deine lokale Administration um Hilfe.",
    "Couldn't send reset email. Please contact your administrator." : "Die E-Mail zum Zurücksetzen konnte nicht gesendet werden. Bitte kontaktiere deine Administration.",
    "Password cannot be changed. Please contact your administrator." : "Passwort kann nicht geändert werden. Bitte wende dich an deine Administration.",
    "New password" : "Neues Passwort",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Deine Dateien sind verschlüsselt. Es gibt keinen Weg deine Dateien nach dem Rücksetzen des Passwortes wiederherzustellen. Falls du dir nicht sicher bist, kontaktiere deine Administration. Möchtest du wirklich fortfahren?",
    "I know what I'm doing" : "Ich weiß, was ich mache",
    "Resetting password" : "Setze Passwort zurück",
    "Schedule work & meetings, synced with all your devices." : "Plane Arbeiten und Besprechungen, die auf deinen Geräten synchronisiert sind.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Halte die Kontakte zu deinen Kollegen und Freunde an einem Ort zusammen, ohne deren privaten Daten zu weiterzugeben.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Einfache E-Mail App mit super integrierter Dateiverwaltung, Adressen und Kalender.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatten, Videoanrufe, Bildschirm teilen, Online-Besprechungen und Webkonferenzen - in Deinem Browser sowie mit mobilen Apps.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Gemeinsame Dokumente, Tabellenkalkulationen und Präsentationen, die auf Collabora Online basieren.",
    "Distraction free note taking app." : "Ablenkungsfreie Notizen-App",
    "Recommended apps" : "Empfohlene Apps",
    "Loading apps …" : "Lade Apps …",
    "Could not fetch list of apps from the App Store." : "Liste der Apps konnte nicht vom App-Store abgerufen werden",
    "App download or installation failed" : "Herunterladen oder Installieren der App fehlgeschlagen",
    "Cannot install this app because it is not compatible" : "App kann nicht installiert werden, da sie inkompatibel ist",
    "Cannot install this app" : "App kann nicht installiert werden",
    "Skip" : "Überspringen",
    "Installing apps …" : "Installiere Apps …",
    "Install recommended apps" : "Empfohlene Apps installieren",
    "Avatar of {displayName}" : "Avatar von {displayName}",
    "Settings menu" : "Einstellungen-Menü",
    "Loading your contacts …" : "Lade deine Kontakte …",
    "Looking for {term} …" : "Suche nach {term} …",
    "Search contacts" : "Kontakte suchen",
    "Reset search" : "Suche zurücksetzen",
    "Search contacts …" : "Kontakte suchen …",
    "Could not load your contacts" : "Deine Kontakte konnten nicht geladen werden",
    "No contacts found" : "Keine Kontakte gefunden",
    "Show all contacts" : "Alle Kontakte anzeigen",
    "Install the Contacts app" : "Kontakte-App installieren",
    "Search" : "Suche",
    "No results for {query}" : "Keine Suchergebnisse zu {query}",
    "Press Enter to start searching" : "Zum Suchen EIngabetaste drücken",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Bitte gebe {minSearchLength} Zeichen oder mehr ein nach denen gesucht werden soll","Bitte gib {minSearchLength} oder mehr Zeichen ein, nach denen gesucht werden soll"],
    "An error occurred while searching for {type}" : "Es ist ein Fehler beim Suchen nach {type} aufgetreten",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Die Suche beginnt, sobald du mit der Eingabe beginnst. Die Suchergebnisse kannst du mit den Pfeiltasten auswählen,",
    "Search for {name} only" : "Nur nach {name} suchen",
    "Loading more results …" : "Lade weitere Ergebnisse …",
    "Forgot password?" : "Passwort vergessen?",
    "Back to login form" : "Zurück zum Anmeldeformular",
    "Back" : "Zurück",
    "Login form is disabled." : "Das Anmeldeformular ist deaktiviert.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Das Nextcloud-Anmeldeformular ist deaktiviert. Nutze ggf. eine andere Anmeldemöglichkeit oder wende dich an deine Administration.",
    "More actions" : "Weitere Aktionen",
    "User menu" : "Benutzermenü",
    "Your guest name: {user}" : "Dein Gastname: {user}",
    "You are currently not identified." : "Du bist derzeit nicht identifiziert.",
    "Set public name" : "Öffentlichen Namen festlegen",
    "Change public name" : "Öffentlichen Namen ändern",
    "Password is too weak" : "Passwort ist zu schwach",
    "Password is weak" : "Passwort ist schwach",
    "Password is average" : "Passwort ist durchschnittlich",
    "Password is strong" : "Passwort ist stark",
    "Password is very strong" : "Passwort ist sehr stark",
    "Password is extremely strong" : "Passwort ist extrem stark",
    "Unknown password strength" : "Unbekannte Passwortstärke",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Dein Datenverzeichnis und deine Dateien sind wahrscheinlich über das Internet zugänglich, da die <code>.htaccess</code>-Datei nicht funktioniert.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Informationen zur ordnungsgemäßen Konfiguration des Servers sind {linkStart}in der Dokumentation zu finden{linkEnd}",
    "Autoconfig file detected" : "Autoconfig-Datei erkannt",
    "The setup form below is pre-filled with the values from the config file." : "Das folgende Einrichtungsformular ist mit den Werten aus der Konfigurationsdatei vorausgefüllt.",
    "Security warning" : "Sicherheitswarnung",
    "Create administration account" : "Administrationskonto erstellen",
    "Administration account name" : "Name des Administrationskontos",
    "Administration account password" : "Passwort des Administrationskontos",
    "Storage & database" : "Speicher & Datenbank",
    "Data folder" : "Datenverzeichnis",
    "Database configuration" : "Datenbankkonfiguration",
    "Database type" : "Datenbank-Typ",
    "Only {firstAndOnlyDatabase} is available." : "Nur {firstAndOnlyDatabase} ist verfügbar",
    "Install and activate additional PHP modules to choose other database types." : "Um weitere Datenbank-Typen auswählen zu können, müssen zusätzliche PHP-Module installiert und aktiviert werden.",
    "For more details check out the documentation." : "Schau für weitere Informationen in die Dokumentation.",
    "Performance warning" : "Leistungswarnung",
    "You chose SQLite as database." : "Du hast SQLite als Datenbanktyp ausgewählt.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite sollte nur für Minimal- und Entwicklungsinstanzen gewählt werden. Für die Produktion wird ein anderes Datenbank-Backend empfohlen.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Wenn Clients für die Dateisynchronisierung verwenden werden, so wird von der Verwendung von SQLite dringend abgeraten.",
    "Database connection" : "Datenbankverbindung",
    "Database user" : "Datenbank-Benutzer",
    "Database password" : "Datenbank-Passwort",
    "Database name" : "Datenbank-Name",
    "Database tablespace" : "Datenbank-Tablespace",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Bitte die Portnummer mit der Hostadresse zusammen angeben (z. B. localhost:5432)",
    "Database host" : "Datenbank-Host",
    "localhost" : "localhost",
    "Installing …" : "Installiere …",
    "Install" : "Installieren",
    "Need help?" : "Hilfe nötig?",
    "See the documentation" : "Schau in die Dokumentation",
    "{name} version {version} and above" : "{name} Version {version} und neuer",
    "This browser is not supported" : "Dieser Browser wird nicht unterstützt.",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Dein Browser wird nicht unterstützt. Bitte aktualisieren deinen Browser auf eine neuere oder unterstützte Version.",
    "Continue with this unsupported browser" : "Mit diesem nicht unterstützten Browser fortfahren.",
    "Supported versions" : "Unterstützte Versionen",
    "Search {types} …" : "Suche {types} …",
    "Choose {file}" : "{file} auswählen",
    "Choose" : "Auswählen",
    "Copy to {target}" : "Nach {target} kopieren",
    "Copy" : "Kopieren",
    "Move to {target}" : "Nach {target} verschieben",
    "Move" : "Verschieben",
    "OK" : "OK",
    "read-only" : "Schreibgeschützt",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} Dateikonflikt","{count} Dateikonflikte"],
    "One file conflict" : "Ein Dateikonflikt",
    "New Files" : "Neue Dateien",
    "Already existing files" : "Bereits existierende Dateien",
    "Which files do you want to keep?" : "Welche Dateien sollen erhalten bleiben?",
    "If you select both versions, the copied file will have a number added to its name." : "Falls beide Versionen gewählt werden, wird bei der kopierten Datei eine Zahl am Ende des Dateinamens hinzugefügt.",
    "Cancel" : "Abbrechen",
    "Continue" : "Fortsetzen",
    "(all selected)" : "(Alle ausgewählt)",
    "({count} selected)" : "({count} ausgewählt)",
    "Error loading file exists template" : "Fehler beim Laden der vorhanden Dateivorlage",
    "Saving …" : "Speichere …",
    "seconds ago" : "Gerade eben",
    "Connection to server lost" : "Verbindung zum Server verloren",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem beim Laden der Seite, Seite wird in %n Sekunde nochmals geladen","Problem beim Laden der Seite, Seite wird in %n Sekunden erneut geladen"],
    "Add to a project" : "Zu einem Projekt hinzufügen",
    "Show details" : "Details anzeigen",
    "Hide details" : "Details ausblenden",
    "Rename project" : "Projekt umbenennen",
    "Failed to rename the project" : "Projekt konnte nicht umbenannt werden",
    "Failed to create a project" : "Projekt konnte nicht erstellt werden",
    "Failed to add the item to the project" : "Eintrag konnte nicht zum Projekt hinzu gefügt werden",
    "Connect items to a project to make them easier to find" : "Zum leichten Auffinden von Einträgen, diese zu einem Projekt hinzufügen",
    "Type to search for existing projects" : "Nach existierenden Projekten suchen",
    "New in" : "Neu in",
    "View changelog" : "Liste der Veränderungen ansehen",
    "Close \"{dialogTitle}\" dialog" : "Dialog \"{dialogTitle}\" schließen",
    "Email length is at max (255)" : "Maximale Länge der E-Mail-Adresse erreicht (255)",
    "Clipboard not available, please copy manually" : "Zwischenablage nicht verfügbar, bitte manuell kopieren",
    "Personal" : "Persönlich",
    "Accounts" : "Konten",
    "Admin" : "Administration",
    "Help" : "Hilfe",
    "Access forbidden" : "Zugriff verboten",
    "You are not allowed to access this page." : "Du darfst diese Seite nicht aufrufen.",
    "Back to %s" : "Zurück zu %s",
    "Page not found" : "Seite nicht gefunden",
    "The page could not be found on the server or you may not be allowed to view it." : "Die Seite konnte auf dem Server nicht gefunden werden oder du bist nicht berechtigt sie anzusehen.",
    "Too many requests" : "Zu viele Anfragen",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zu viele Anfragen aus deinem Netzwerk. Versuche es später erneut oder wende dich an deine Administration, wenn dies ein Fehler sein sollte.",
    "Error" : "Fehler",
    "Internal Server Error" : "Interner Serverfehler",
    "The server was unable to complete your request." : "Der Server konnte die Anfrage nicht fertig stellen.",
    "If this happens again, please send the technical details below to the server administrator." : "Sollte dies erneut auftreten, sende bitte die nachfolgenden technischen Einzelheiten an deine Serveradministration.",
    "More details can be found in the server log." : "Weitere Details können im Serverprotokoll gefunden werden.",
    "For more details see the documentation ↗." : "Weitere Informationen finden Sie in der Dokumentation ↗.",
    "Technical details" : "Technische Details",
    "Remote Address: %s" : "Entfernte Adresse: %s",
    "Request ID: %s" : "Anfragekennung: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Code: %s",
    "Message: %s" : "Nachricht: %s",
    "File: %s" : "Datei: %s",
    "Line: %s" : "Zeile: %s",
    "Trace" : "Trace",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Es sieht so aus, als ob du Nextcloud erneut installieren möchtest. Es fehlt jedoch die Datei CAN_INSTALL in deinem Konfigurationsordner. Bitte erstelle die Datei CAN_INSTALL im Konfigurationsordner um fortzufahren.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "CAN_INSTALL konnte nicht aus dem Konfigurationsordner entfernt werden. Bitte entferne die Datei manuell.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Diese Anwendung benötigt JavaScript zum ordnungsgemäßen Betrieb. Bitte {linkstart}aktiviere JavaScript{linkend} und lade die Seite neu.",
    "Skip to main content" : "Zum Hauptinhalt springen",
    "Skip to navigation of app" : "Zum Navigationsbereich der App springen",
    "Go to %s" : "%s aufrufen",
    "Get your own free account" : "Hole dir dein eigenes kostenloses Konto",
    "Connect to your account" : "Verbinde dich mit deinem Konto",
    "Please log in before granting %1$s access to your %2$s account." : "Bitte melde dich an, bevor du %1$s Zugriff auf dein %2$s-Konto gewährst.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Solltest du aktuell nicht versuchen, ein neues Gerät oder eine neue App einzurichten, dann kann es sein, dass jemand versucht, dich dazu zu bewegen, ihm Zugriff auf deine Daten zu gewähren. Fahre in diesem Fall nicht fort, sondern wende dich an deine Administration.",
    "App password" : "App-Passwort",
    "Grant access" : "Zugriff gewähren",
    "Alternative log in using app password" : "Alternative Anmeldung mittels App-Passwort",
    "Account access" : "Kontozugriff ",
    "Currently logged in as %1$s (%2$s)." : "Aktuell angemeldet als %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Du bist dabei, %1$s Zugriff auf dein %2$s-Konto zu gewähren.",
    "Account connected" : "Konto verbunden",
    "Your client should now be connected!" : "Dein Client sollte nun verbunden sein!",
    "You can close this window." : "Du kannst dieses Fenster schließen.",
    "Previous" : "Vorige",
    "This share is password-protected" : "Diese Freigabe ist passwortgeschützt",
    "The password is wrong or expired. Please try again or request a new one." : "Das Passwort ist falsch oder abgelaufen. Bitte versuche es erneut oder forder ein neues Passwort an.",
    "Please type in your email address to request a temporary password" : "Bitte gib deine E-Mail-Adresse ein, um ein vorläufiges Passwort anzufordern",
    "Email address" : "E-Mail-Adresse",
    "Password sent!" : "Passwort wurde verschickt",
    "You are not authorized to request a password for this share" : "Du bist nicht berechtigt, für diese Freigabe ein Passwort anzufordern",
    "Two-factor authentication" : "Zwei-Faktor-Authentifizierung",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Die erweiterte Sicherheit wurde für dein Konto aktiviert. Bitte wähle einen zweiten Faktor für die Authentifizierung:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Mindestens eine deiner Zwei-Faktor-Authentifizierungsmethoden konnte nicht geladen werden. Kontaktiere deine Administration.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Die Zwei-Faktor-Authentifizierung wird erzwungen, wurde jedoch für dein Konto nicht konfiguriert. Wende dich für Unterstützung an deine Administration.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Die Zwei-Faktor-Authentifizierung wird erzwungen, wurde jedoch für dein Konto nicht konfiguriert. Bitte fahre mit der Einrichtung der Zwei-Faktor-Authentifizierung fort.",
    "Set up two-factor authentication" : "Zwei-Faktor-Authentifizierung konfigurieren",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Die Zwei-Faktor-Authentifizierung wird erzwungen, wurde jedoch für dein Konto nicht konfiguriert. Verwende einen deiner Backup-Codes zum Anmelden, oder wende dich für Unterstützung an deine Administration.",
    "Use backup code" : "Backup-Code benutzen",
    "Cancel login" : "Anmeldung abbrechen",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Erhöhte Sicherheit ist für dein Konto aktiviert. Bitte wähle einen Anbieter zum Einrichten: ",
    "Error while validating your second factor" : "Fehler beim Bestätigen des zweiten Sicherheitsfaktors",
    "Access through untrusted domain" : "Zugriff über eine nicht vertrauenswürdige Domain",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Bitte kontaktiere deine Administration. Wenn du der Administration angehörst,  bearbeite die \"trusted_domains\"-Einstellung in config/config.php. Siehe Beispiel in config/config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Weitere Informationen zur Konfiguration finden sich in der %1$sDokumentation%2$s.",
    "App update required" : "App-Aktualisierung notwendig",
    "%1$s will be updated to version %2$s" : "%1$s wird auf Version %2$s aktualisiert",
    "The following apps will be updated:" : "Folgende Apps werden aktualisiert:",
    "These incompatible apps will be disabled:" : "Diese inkompatiblen Apps werden deaktiviert:",
    "The theme %s has been disabled." : "Das Design %s wurde deaktiviert.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bitte stelle vor dem Fortsetzen sicher, dass die Datenbank, der Konfigurationsordner und der Datenordner gesichert wurden.",
    "Start update" : "Aktualisierung starten",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Zur Vermeidung von Zeitüberschreitungen bei größeren Installationen kannst du stattdessen den folgenden Befehl in deinem Installationsverzeichnis ausführen:",
    "Detailed logs" : "Detaillierte Protokollmeldungen",
    "Update needed" : "Aktualisierung erforderlich",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Bitte verwende den Kommandozeilen-Updater, da du eine große Installation mit mehr als 50 Konten betreibst.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Für weitere Hilfen, schaue bitte in die <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">Dokumentation</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Mir ist bekannt, dass die Durchführung der Aktualisierung über die Web-Oberfläche das Risiko birgt, dass der Aktualisierungsprozess abgebrochen wird, was zu Datenverlust führen kann. Ich habe eine Sicherung und ich weiss, wie ich im Falle eines Fehlers beim Aktualisieren meine Installation wieder herstellen kann.",
    "Upgrade via web on my own risk" : "Aktualisierung über die Web-Oberfläche auf eigenes Risiko",
    "Maintenance mode" : "Wartungsmodus",
    "This %s instance is currently in maintenance mode, which may take a while." : "Diese Instanz der %s - befindet sich gerade im Wartungsmodus, was eine Weile dauern kann.",
    "This page will refresh itself when the instance is available again." : "Diese Seite aktualisiert sich automatisch, sobald diese Instanz wieder verfügbar ist.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktiere die Systemadministration, wenn diese Meldung dauerhaft oder unerwartet erscheint.",
    "Error occurred while checking server setup" : "Fehler beim Überprüfen der Servereinrichtung",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Weitere Informationen findest du in der {linkstart}Dokumentation ↗{linkend}.",
    "unknown text" : "Unbekannter Text",
    "Hello world!" : "Hallo Welt!",
    "sunny" : "sonnig",
    "Hello {name}, the weather is {weather}" : "Hallo {name}, das Wetter ist {weather}",
    "Hello {name}" : "Hallo {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dies sind deine Suchergebnisse<script>alert(1)</script></strong>",
    "new" : "Neu",
    "_download %n file_::_download %n files_" : ["Lade %n Datei herunter","Lade %n Dateien herunter"],
    "Direct link copied to clipboard" : "Direkter Link in die Zwischenablage kopiert",
    "Searching …" : "Suche …",
    "Logging in …" : "Melde an…",
    "Loading apps …" : "Lade Apps …",
    "Installing apps …" : "Installiere Apps …",
    "Loading your contacts …" : "Lade deine Kontakte …",
    "Looking for {term} …" : "Suche nach {term} …",
    "Search contacts …" : "Kontakte suchen …",
    "Loading more results …" : "Lade weitere Ergebnisse …",
    "Search {types} …" : "Suche {types} …",
    "Saving …" : "Speichern …",
    "Very weak password" : "Sehr schwaches Passwort",
    "Weak password" : "Schwaches Passwort",
    "So-so password" : "Passables Passwort",
    "Good password" : "Gutes Passwort",
    "Strong password" : "Starkes Passwort",
    "No action available" : "Keine Aktion verfügbar",
    "Error fetching contact actions" : "Fehler beim Einlesen der Kontakt-Aktionen",
    "Non-existing tag #{tag}" : "Nicht existierender Tag #{tag}",
    "Restricted" : "Eingeschränkt",
    "Invisible" : "Unsichtbar",
    "Delete" : "Löschen",
    "Rename" : "Umbenennen",
    "Collaborative tags" : "Kollaborative Schlagworte",
    "No tags found" : "Keine Tags gefunden",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Dein Datenverzeichnis und deine Dateien sind wahrscheinlich vom Internet aus erreichbar, weil die .htaccess-Datei nicht funktioniert.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informationen zum richtigen Konfigurieren deines Servers kannst du der <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">Dokumentation</a> entnehmen.",
    "<strong>Create an admin account</strong>" : "<strong>Administrationskonto anlegen</strong>",
    "New admin account name" : "Neuer Administrationskontoname",
    "New admin password" : "Neues Administrationskennwort",
    "Show password" : "Passwort anzeigen",
    "Toggle password visibility" : "Passwortsichtbarkeit umschalten",
    "Configure the database" : "Datenbank einrichten",
    "Only %s is available." : "Es ist nur %s verfügbar.",
    "Database account" : "Datenbankkonto",
    "Installing …" : "Installiere …"
},
"nplurals=2; plural=(n != 1);");
